Documentation

Overview

Package subtle implements functions that are often useful in cryptographic code but require careful thought to use correctly.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AnyOverlap

func AnyOverlap(x, y []byte) bool

AnyOverlap reports whether x and y share memory at any (not necessarily corresponding) index. The memory beyond the slice length is ignored.

func InexactOverlap

func InexactOverlap(x, y []byte) bool

InexactOverlap reports whether x and y share memory at any non-corresponding index. The memory beyond the slice length is ignored. Note that x and y can have different lengths and still not have any inexact overlap.

InexactOverlap can be used to implement the requirements of the crypto/cipher AEAD, Block, BlockMode and Stream interfaces.

Types

This section is empty.

Source Files